@@ -18,6 +18,10 @@ def default_handler_class_manager(HandlerCls:type,is_behavior:bool=False):
 
 
 def __get_result_block__(resp: Awaitable):
+    current_loop = asyncio.get_event_loop()
+    if current_loop and not current_loop.is_closed():
+        return current_loop.run_until_complete(resp)
+
     loop = asyncio.new_event_loop()
     results = loop.run_until_complete(resp)
     loop.close()
@@ -52,9 +56,6 @@ def find_behaviors(request):
 
 
 class Mediator():
-    pass
-
-class Mediator(Mediator):
     """Class of mediator as entry point to send requests and get responses"""
 
     handler_class_manager = default_handler_class_manager
@@ -63,7 +64,7 @@ class Mediator(Mediator):
         if handler_class_manager:
             self.handler_class_manager = handler_class_manager
 
-    async def send_async(self: Union[Mediator,GenericQuery[TResponse]], request: Optional[GenericQuery[TResponse]] = None) -> Awaitable[TResponse]:
+    async def send_async(self: Union["Mediator",GenericQuery[TResponse]], request: Optional[GenericQuery[TResponse]] = None) -> Awaitable[TResponse]:
         """
         Send request in async mode and getting response
 
@@ -107,7 +108,7 @@ class Mediator(Mediator):
             return await __return_await__(next(gen))
         return await next_func()
 
-    def send(self: Union[Mediator, GenericQuery[TResponse]], request: Optional[GenericQuery[TResponse]] = None) -> TResponse:
+    def send(self: Union["Mediator", GenericQuery[TResponse]], request: Optional[GenericQuery[TResponse]] = None) -> TResponse:
         """
         Send request in synchronous mode and getting response
         
